@@ -255,12 +255,10 @@ webkit_pref_callback_user_javascript (GSettings  *settings,
                      (GAsyncReadyCallback)user_javascript_read_cb, NULL);
 
   user_javascript_monitor = g_file_monitor_file (file, G_FILE_MONITOR_NONE, NULL, &error);
-  if (!user_javascript_monitor) {
+  if (!user_javascript_monitor)
     g_warning ("Could not create a file monitor for %s: %s\n", g_file_get_uri (file), error->message);
-    g_error_free (error);
-  } else {
+  else
     g_signal_connect (user_javascript_monitor, "changed", G_CALLBACK (user_javascript_file_changed), NULL);
-  }
 }
 
 static void
@@ -454,8 +452,8 @@ webkit_pref_callback_enable_website_data_storage (GSettings  *settings,
                                                   const char *key,
                                                   gpointer    data)
 {
-  EphyEmbedShell *shell;
-  WebKitWebContext *context;
+  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
+  WebKitNetworkSession *network_session;
   WebKitCookieManager *manager;
   gboolean value;
 
@@ -463,9 +461,8 @@ webkit_pref_callback_enable_website_data_storage (GSettings  *settings,
   webkit_settings_set_enable_html5_database (webkit_settings, value);
   webkit_settings_set_enable_html5_local_storage (webkit_settings, value);
 
-  shell = ephy_embed_shell_get_default ();
-  context = ephy_embed_shell_get_web_context (shell);
-  manager = webkit_web_context_get_cookie_manager (context);
+  network_session = ephy_embed_shell_get_network_session (shell);
+  manager = webkit_network_session_get_cookie_manager (network_session);
   webkit_cookie_manager_set_accept_policy (manager, value ? WEBKIT_COOKIE_POLICY_ACCEPT_ALWAYS : WEBKIT_COOKIE_POLICY_ACCEPT_NEVER);
 }
 
@@ -478,19 +475,15 @@ webkit_pref_callback_hardware_acceleration_policy (GSettings  *settings,
 
   value = g_settings_get_enum (settings, key);
   switch (value) {
-    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS:
-      webkit_settings_set_hardware_acceleration_policy (webkit_settings,
-                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_ALWAYS);
-      break;
     case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_NEVER:
       webkit_settings_set_hardware_acceleration_policy (webkit_settings,
                                                         WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER);
       break;
-    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ON_DEMAND:
+    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS:
     /* Fallthrough */
     default:
       webkit_settings_set_hardware_acceleration_policy (webkit_settings,
-                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_ON_DEMAND);
+                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_ALWAYS);
       break;
   }
 }
@@ -564,9 +557,7 @@ ephy_embed_prefs_init (gpointer user_data)
   guint i;
 
   webkit_settings = webkit_settings_new_with_settings ("enable-back-forward-navigation-gestures", TRUE,
-                                                       "enable-developer-extras", TRUE,
                                                        "enable-dns-prefetching", TRUE,
-                                                       "enable-plugins", FALSE,
                                                        "enable-media-stream", TRUE,
                                                        "enable-smooth-scrolling", TRUE,
                                                        "javascript-can-open-windows-automatically", TRUE,
@@ -593,6 +584,10 @@ ephy_embed_prefs_init (gpointer user_data)
                    EPHY_PREFS_ENABLE_CARET_BROWSING,
                    webkit_settings, "enable-caret-browsing",
                    G_SETTINGS_BIND_GET);
+  g_settings_bind (EPHY_SETTINGS_WEB,
+                   EPHY_PREFS_WEB_SHOW_DEVELOPER_ACTIONS,
+                   webkit_settings, "enable-developer-extras",
+                   G_SETTINGS_BIND_GET);
   g_settings_bind (EPHY_SETTINGS_WEB,
                    EPHY_PREFS_WEB_FONT_MIN_SIZE,
                    webkit_settings, "minimum-font-size",
