@@ -55,7 +55,6 @@ typedef struct {
   WebKitWebContext *web_context;
   WebKitNetworkSession *network_session;
   EphyHistoryService *global_history_service;
-  EphyGSBService *global_gsb_service;
   EphyEncodings *encodings;
   GtkPageSetup *page_setup;
   GtkPrintSettings *print_settings;
@@ -75,9 +74,6 @@ typedef struct {
 enum {
   RESTORED_WINDOW,
   WEB_VIEW_CREATED,
-  ALLOW_TLS_CERTIFICATE,
-  ALLOW_UNSAFE_BROWSING,
-  RELOAD_PAGE,
   PASSWORD_FORM_FOCUSED,
   PASSWORD_FORM_SUBMITTED,
 
@@ -192,7 +188,6 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->page_setup);
   g_clear_object (&priv->print_settings);
   g_clear_object (&priv->global_history_service);
-  g_clear_object (&priv->global_gsb_service);
   g_clear_object (&priv->about_handler);
   g_clear_object (&priv->reader_handler);
   g_clear_object (&priv->source_handler);
@@ -299,50 +294,6 @@ web_process_extension_overview_message_received_cb (WebKitUserContentManager *ma
                                        shell);
 }
 
-static void
-web_process_extension_tls_error_page_message_received_cb (WebKitUserContentManager *manager,
-                                                          JSCValue                 *message,
-                                                          EphyEmbedShell           *shell)
-{
-  guint64 page_id;
-
-  page_id = jsc_value_to_double (message);
-  g_signal_emit (shell, signals[ALLOW_TLS_CERTIFICATE], 0, page_id);
-}
-
-static void
-web_process_extension_reload_page_message_received_cb (WebKitUserContentManager *manager,
-                                                       JSCValue                 *message,
-                                                       EphyEmbedShell           *shell)
-{
-  guint64 page_id;
-
-  page_id = jsc_value_to_double (message);
-  g_signal_emit (shell, signals[RELOAD_PAGE], 0, page_id);
-}
-
-static void
-web_process_extension_unsafe_browsing_error_page_message_received_cb (WebKitUserContentManager *manager,
-                                                                      JSCValue                 *message,
-                                                                      EphyEmbedShell           *shell)
-{
-  guint64 page_id;
-
-  page_id = jsc_value_to_double (message);
-  g_signal_emit (shell, signals[ALLOW_UNSAFE_BROWSING], 0, page_id);
-}
-
-static void
-web_process_extension_about_apps_message_received_cb (WebKitUserContentManager *manager,
-                                                      JSCValue                 *message,
-                                                      EphyEmbedShell           *shell)
-{
-  g_autofree char *app_id = NULL;
-
-  app_id = jsc_value_to_string (message);
-  ephy_web_application_delete (app_id, NULL);
-}
-
 static char *
 property_to_string_or_null (JSCValue   *value,
                             const char *name)
@@ -594,30 +545,6 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
   return priv->global_history_service;
 }
 
-/**
- * ephy_embed_shell_get_global_gsb_service:
- * @shell: the #EphyEmbedShell
- *
- * Return value: (transfer none): the global #EphyGSBService
- **/
-EphyGSBService *
-ephy_embed_shell_get_global_gsb_service (EphyEmbedShell *shell)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  g_assert (EPHY_IS_EMBED_SHELL (shell));
-
-  if (!priv->global_gsb_service) {
-    g_autofree char *db_path = NULL;
-    g_autofree char *default_cache_dir = ephy_default_cache_dir ();
-
-    db_path = g_build_filename (default_cache_dir, EPHY_GSB_FILE, NULL);
-    priv->global_gsb_service = ephy_gsb_service_new (GSB_API_KEY, db_path);
-  }
-
-  return priv->global_gsb_service;
-}
-
 /**
  * ephy_embed_shell_get_encodings:
  * @shell: the #EphyEmbedShell
@@ -1026,8 +953,7 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
     g_signal_new ("window-restored",
                   EPHY_TYPE_EMBED_SHELL,
                   G_SIGNAL_RUN_FIRST,
-                  G_STRUCT_OFFSET (EphyEmbedShellClass, restored_window),
-                  NULL, NULL, NULL,
+                  0, NULL, NULL, NULL,
                   G_TYPE_NONE,
                   0);
 
@@ -1048,55 +974,6 @@ ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
                   G_TYPE_NONE, 1,
                   EPHY_TYPE_WEB_VIEW);
 
-  /**
-   * EphyEmbedShell::allow-tls-certificate:
-   * @shell: the #EphyEmbedShell
-   * @page_id: the identifier of the web page
-   *
-   * Emitted when the web process extension requests an exception be
-   * permitted for the invalid TLS certificate on the given page
-   */
-  signals[ALLOW_TLS_CERTIFICATE] =
-    g_signal_new ("allow-tls-certificate",
-                  EPHY_TYPE_EMBED_SHELL,
-                  G_SIGNAL_RUN_FIRST,
-                  0, NULL, NULL, NULL,
-                  G_TYPE_NONE, 1,
-                  G_TYPE_UINT64);
-
-  /**
-   * EphyEmbedShell::allow-unsafe-browsing:
-   * @shell: the #EphyEmbedShell
-   * @page_id: the identifier of the web page
-   *
-   * Emitted when the web process extension requests an exception be
-   * permitted for the unsafe browsing warning on the given page
-   */
-  signals[ALLOW_UNSAFE_BROWSING] =
-    g_signal_new ("allow-unsafe-browsing",
-                  EPHY_TYPE_EMBED_SHELL,
-                  G_SIGNAL_RUN_FIRST,
-                  0, NULL, NULL, NULL,
-                  G_TYPE_NONE, 1,
-                  G_TYPE_UINT64);
-
-  /**
-   * EphyEmbedShell::reload-page:
-   * @shell: the #EphyEmbedShell
-   * @page_id: the identifier of the web page
-   *
-   * Emitted when the web process extension requests a view be reloaded.
-   * This is needed when window.location.reload() doesn't work properly,
-   * specifically after loading alternate HTML.
-   */
-  signals[RELOAD_PAGE] =
-    g_signal_new ("reload-page",
-                  EPHY_TYPE_EMBED_SHELL,
-                  G_SIGNAL_RUN_FIRST,
-                  0, NULL, NULL, NULL,
-                  G_TYPE_NONE, 1,
-                  G_TYPE_UINT64);
-
   /**
    * EphyEmbedShell::password-form-focused
    * @shell: the #EphyEmbedShell
@@ -1349,13 +1226,19 @@ ephy_embed_shell_get_favicon_database (EphyEmbedShell *shell)
 }
 
 void
-ephy_embed_shell_register_ucm_handler (EphyEmbedShell           *shell,
-                                       WebKitUserContentManager *ucm)
+ephy_embed_shell_register_ucm (EphyEmbedShell           *shell,
+                               WebKitUserContentManager *ucm)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
-  /* User content manager */
-  /* FIXME: See https://gitlab.gnome.org/GNOME/epiphany/-/issues/1664 */
+  /* Warning: message handlers connected here should use the private script
+   * world priv->guid to make them unavailable to web content. If a message
+   * handler needs to be temporarily accessible to web content in order to
+   * implement internal Epiphany pages, register it using
+   * ephy_web_view_register_message_handler() to ensure it is unregistered
+   * before any subsequent page load.
+   */
+
   webkit_user_content_manager_register_script_message_handler (ucm,
                                                                "overview",
                                                                priv->guid);
@@ -1363,27 +1246,6 @@ ephy_embed_shell_register_ucm_handler (EphyEmbedShell           *shell,
                            G_CALLBACK (web_process_extension_overview_message_received_cb),
                            shell, 0);
 
-  webkit_user_content_manager_register_script_message_handler (ucm,
-                                                               "tlsErrorPage",
-                                                               NULL);
-  g_signal_connect_object (ucm, "script-message-received::tlsErrorPage",
-                           G_CALLBACK (web_process_extension_tls_error_page_message_received_cb),
-                           shell, 0);
-
-  webkit_user_content_manager_register_script_message_handler (ucm,
-                                                               "reloadPage",
-                                                               NULL);
-  g_signal_connect_object (ucm, "script-message-received::reloadPage",
-                           G_CALLBACK (web_process_extension_reload_page_message_received_cb),
-                           shell, 0);
-
-  webkit_user_content_manager_register_script_message_handler (ucm,
-                                                               "unsafeBrowsingErrorPage",
-                                                               NULL);
-  g_signal_connect_object (ucm, "script-message-received::unsafeBrowsingErrorPage",
-                           G_CALLBACK (web_process_extension_unsafe_browsing_error_page_message_received_cb),
-                           shell, 0);
-
   webkit_user_content_manager_register_script_message_handler (ucm,
                                                                "passwordFormFocused",
                                                                priv->guid);
@@ -1391,13 +1253,6 @@ ephy_embed_shell_register_ucm_handler (EphyEmbedShell           *shell,
                            G_CALLBACK (web_process_extension_password_form_focused_message_received_cb),
                            shell, 0);
 
-  webkit_user_content_manager_register_script_message_handler (ucm,
-                                                               "aboutApps",
-                                                               NULL);
-  g_signal_connect_object (ucm, "script-message-received::aboutApps",
-                           G_CALLBACK (web_process_extension_about_apps_message_received_cb),
-                           shell, 0);
-
   webkit_user_content_manager_register_script_message_handler (ucm,
                                                                "passwordManagerSave",
                                                                priv->guid);
@@ -1432,29 +1287,20 @@ ephy_embed_shell_register_ucm_handler (EphyEmbedShell           *shell,
 }
 
 void
-ephy_embed_shell_unregister_ucm_handler (EphyEmbedShell           *shell,
-                                         WebKitUserContentManager *ucm)
+ephy_embed_shell_unregister_ucm (EphyEmbedShell           *shell,
+                                 WebKitUserContentManager *ucm)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
   webkit_user_content_manager_unregister_script_message_handler (ucm,
                                                                  "overview",
                                                                  priv->guid);
-  webkit_user_content_manager_unregister_script_message_handler (ucm,
-                                                                 "tlsErrorPage",
-                                                                 NULL);
-  webkit_user_content_manager_unregister_script_message_handler (ucm,
-                                                                 "unsafeBrowsingErrorPage",
-                                                                 NULL);
   webkit_user_content_manager_unregister_script_message_handler (ucm,
                                                                  "passwordManagerRequestSave",
                                                                  priv->guid);
   webkit_user_content_manager_unregister_script_message_handler (ucm,
                                                                  "passwordFormFocused",
                                                                  priv->guid);
-  webkit_user_content_manager_unregister_script_message_handler (ucm,
-                                                                 "aboutApps",
-                                                                 NULL);
   webkit_user_content_manager_unregister_script_message_handler (ucm,
                                                                  "passwordManagerSave",
                                                                  priv->guid);
