@@ -21,12 +21,11 @@
 
 #pragma once
 
-#include <dazzle.h>
-#include <webkit2/webkit2.h>
+#include <adwaita.h>
+#include <webkit/webkit.h>
 
 #include "ephy-downloads-manager.h"
 #include "ephy-encodings.h"
-#include "ephy-gsb-service.h"
 #include "ephy-history-service.h"
 #include "ephy-password-manager.h"
 #include "ephy-permissions-manager.h"
@@ -38,7 +37,7 @@ typedef struct _EphyFiltersManager EphyFiltersManager;
 
 #define EPHY_TYPE_EMBED_SHELL (ephy_embed_shell_get_type ())
 
-G_DECLARE_DERIVABLE_TYPE (EphyEmbedShell, ephy_embed_shell, EPHY, EMBED_SHELL, DzlApplication)
+G_DECLARE_DERIVABLE_TYPE (EphyEmbedShell, ephy_embed_shell, EPHY, EMBED_SHELL, AdwApplication)
 
 typedef enum
 {
@@ -54,17 +53,15 @@ typedef enum
 
 struct _EphyEmbedShellClass
 {
-  DzlApplicationClass parent_class;
-
-  void    (* restored_window)  (EphyEmbedShell *shell);
+  AdwApplicationClass parent_class;
 };
 
 EphyEmbedShell    *ephy_embed_shell_get_default                (void);
 const char        *ephy_embed_shell_get_guid                   (EphyEmbedShell   *shell);
 WebKitWebContext  *ephy_embed_shell_get_web_context            (EphyEmbedShell   *shell);
+WebKitNetworkSession *ephy_embed_shell_get_network_session     (EphyEmbedShell   *shell);
 EphyHistoryService
                   *ephy_embed_shell_get_global_history_service (EphyEmbedShell   *shell);
-EphyGSBService    *ephy_embed_shell_get_global_gsb_service     (EphyEmbedShell   *shell);
 EphyEncodings     *ephy_embed_shell_get_encodings              (EphyEmbedShell   *shell);
 void               ephy_embed_shell_restored_window            (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_page_setup             (EphyEmbedShell   *shell,
@@ -74,7 +71,6 @@ void               ephy_embed_shell_set_print_settings         (EphyEmbedShell
                                                                 GtkPrintSettings *settings);
 GtkPrintSettings  *ephy_embed_shell_get_print_settings         (EphyEmbedShell   *shell);
 EphyEmbedShellMode ephy_embed_shell_get_mode                   (EphyEmbedShell   *shell);
-void               ephy_embed_shell_clear_cache                (EphyEmbedShell   *shell);
 void               ephy_embed_shell_set_thumbnail_path         (EphyEmbedShell   *shell,
                                                                 const char       *url,
                                                                 const char       *path);
@@ -85,10 +81,11 @@ EphyDownloadsManager     *ephy_embed_shell_get_downloads_manager    (EphyEmbedSh
 EphyPermissionsManager   *ephy_embed_shell_get_permissions_manager  (EphyEmbedShell *shell);
 EphySearchEngineManager  *ephy_embed_shell_get_search_engine_manager (EphyEmbedShell *shell);
 EphyPasswordManager      *ephy_embed_shell_get_password_manager      (EphyEmbedShell *shell);
+WebKitFaviconDatabase    *ephy_embed_shell_get_favicon_database      (EphyEmbedShell *shell);
 
-void                     ephy_embed_shell_register_ucm_handler (EphyEmbedShell           *shell,
-                                                                WebKitUserContentManager *ucm);
-void                     ephy_embed_shell_unregister_ucm_handler (EphyEmbedShell           *shell,
-                                                                  WebKitUserContentManager *ucm);
+void                     ephy_embed_shell_register_ucm (EphyEmbedShell           *shell,
+                                                        WebKitUserContentManager *ucm);
+void                     ephy_embed_shell_unregister_ucm (EphyEmbedShell           *shell,
+                                                          WebKitUserContentManager *ucm);
 
 G_END_DECLS
