@@ -25,8 +25,10 @@
 #include "ephy-embed-utils.h"
 
 #include "ephy-about-handler.h"
+#include "ephy-embed-shell.h"
 #include "ephy-prefs.h"
 #include "ephy-reader-handler.h"
+#include "ephy-search-engine-manager.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
 #include "ephy-view-source-handler.h"
@@ -61,13 +63,23 @@ ephy_embed_utils_link_message_parse (const char *message)
 
   /* Then we also want to check if there is more than an email address
    * in the mailto: list.
+   * Splitting is done as defined in the "to" component at
+   * https://datatracker.ietf.org/doc/html/rfc6068#section-2 (so with a comma).
    */
-  splitted_message = g_strsplit_set (status_message, ";", -1);
+  splitted_message = g_strsplit_set (status_message, ",", -1);
   tmp = g_string_new (g_strdup_printf (_("Send an email message to “%s”"),
                                        (splitted_message[0] + 7)));
 
   while (splitted_message [i] != NULL) {
-    g_string_append_printf (tmp, ", “%s”", splitted_message[i]);
+    /* TRANSLATORS: This string is part of the previous translatable string.
+     * It is appended for each extraneous mailto: URI email address. For
+     * example if you have mailto:foo@example.com,bar@example.com,baz@example.com
+     * it will show
+     * Send an email to “foo@example.com”, “bar@example.com”, “baz@example.com”
+     * when you hover such link, at the same place as regular URLs when you hover
+     * a link in a web page.
+     */
+    g_string_append_printf (tmp, _(", “%s”"), splitted_message[i]);
     i++;
   }
 
@@ -132,9 +144,8 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-resource", colonpos) &&
-                     g_ascii_strncasecmp (address, "ephy-source", colonpos) &&
+                     g_ascii_strncasecmp (address, EPHY_VIEW_SOURCE_SCHEME, colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-reader", colonpos) &&
-                     g_ascii_strncasecmp (address, "ephy-pdf", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
                      g_ascii_strncasecmp (address, "inspector", colonpos) &&
                      g_ascii_strncasecmp (address, "webkit", colonpos));
@@ -187,34 +198,6 @@ is_public_domain (const char *address)
   return retval;
 }
 
-static gboolean
-is_bang_search (const char *address)
-{
-  EphyEmbedShell *shell;
-  EphySearchEngineManager *search_engine_manager;
-  char **bangs;
-  GString *buffer;
-
-  shell = ephy_embed_shell_get_default ();
-  search_engine_manager = ephy_embed_shell_get_search_engine_manager (shell);
-  bangs = ephy_search_engine_manager_get_bangs (search_engine_manager);
-
-  for (uint i = 0; bangs[i] != NULL; i++) {
-    buffer = g_string_new (bangs[i]);
-    g_string_append (buffer, " ");
-
-    if (strstr (address, buffer->str) == address) {
-      g_string_free (buffer, TRUE);
-      g_free (bangs);
-      return TRUE;
-    }
-    g_string_free (buffer, TRUE);
-  }
-  g_free (bangs);
-
-  return FALSE;
-}
-
 static gboolean
 is_host_with_port (const char *address)
 {
@@ -224,6 +207,9 @@ is_host_with_port (const char *address)
   if (strchr (address, ' '))
     return FALSE;
 
+  if (g_str_has_suffix (address, "/"))
+    return TRUE;
+
   split = g_strsplit (address, ":", -1);
   if (g_strv_length (split) == 2)
     port = g_ascii_strtoll (split[1], NULL, 10);
@@ -231,6 +217,13 @@ is_host_with_port (const char *address)
   return port != 0;
 }
 
+/* This function checks whether @address can point to a web page.
+ * It accepts as potential sources for web page not only full URI/URLs, but also:
+ * - local absolute file path
+ * - IP address
+ * - host:port
+ * - localhost
+ */
 gboolean
 ephy_embed_utils_address_is_valid (const char *address)
 {
@@ -252,7 +245,6 @@ ephy_embed_utils_address_is_valid (const char *address)
            ephy_embed_utils_address_is_existing_absolute_filename (address) ||
            g_regex_match (get_non_search_regex (), address, 0, NULL) ||
            is_public_domain (address) ||
-           is_bang_search (address) ||
            is_host_with_port (address);
 
   g_clear_object (&info);
@@ -260,22 +252,37 @@ ephy_embed_utils_address_is_valid (const char *address)
   return retval;
 }
 
+static char *
+ensure_host_name_is_lowercase (const char *address)
+{
+  g_autofree gchar *host = ephy_string_get_host_name (address);
+  g_autofree gchar *lowercase_host = NULL;
+
+  if (!host)
+    return g_strdup (address);
+
+  lowercase_host = g_utf8_strdown (host, -1);
+
+  if (strcmp (host, lowercase_host) != 0)
+    return ephy_string_find_and_replace (address, host, lowercase_host);
+  else
+    return g_strdup (address);
+}
+
+/* Does various normalization rules to make sure @input_address ends up
+ * with a URI scheme (e.g. absolute filenames or "localhost"), changes
+ * the URI scheme to something more appropriate when needed and lowercases
+ * the hostname.
+ */
 char *
-ephy_embed_utils_normalize_address (const char *address)
+ephy_embed_utils_normalize_address (const char *input_address)
 {
   char *effective_address = NULL;
+  g_autofree gchar *address = NULL;
 
-  g_assert (address);
+  g_assert (input_address);
 
-  if (is_bang_search (address)) {
-    EphyEmbedShell *shell;
-    EphySearchEngineManager *search_engine_manager;
-
-    shell = ephy_embed_shell_get_default ();
-    search_engine_manager = ephy_embed_shell_get_search_engine_manager (shell);
-    return ephy_search_engine_manager_parse_bang_search (search_engine_manager,
-                                                         address);
-  }
+  address = ensure_host_name_is_lowercase (input_address);
 
   if (ephy_embed_utils_address_is_existing_absolute_filename (address))
     return g_strconcat ("file://", address, NULL);
@@ -287,21 +294,21 @@ ephy_embed_utils_normalize_address (const char *address)
     return g_strconcat (EPHY_ABOUT_SCHEME, address + strlen ("about"), NULL);
 
   if (!ephy_embed_utils_address_has_web_scheme (address)) {
-    g_autoptr (SoupURI) uri = NULL;
+    const char *scheme;
 
-    uri = soup_uri_new (address);
+    scheme = g_uri_peek_scheme (address);
 
     /* Auto-prepend http:// to anything that is not
-     * one according to soup, because it probably will be
+     * one according to GLib, because it probably will be
      * something like "google.com". Special case localhost(:port)
-     * and IP(:port), because SoupURI, correctly, thinks it is a
+     * and IP(:port), because GUri, correctly, thinks it is a
      * URI with scheme being localhost/IP and, optionally, path
      * being the port. Ideally we should check if we have a
      * handler for the scheme, and since we'll fail for localhost
      * and IP, we'd fallback to loading it as a domain. */
-    if (!uri ||
-        !g_strcmp0 (uri->scheme, "localhost") ||
-        g_hostname_is_ip_address (uri->scheme) ||
+    if (!scheme ||
+        !g_strcmp0 (scheme, "localhost") ||
+        g_hostname_is_ip_address (scheme) ||
         is_host_with_port (address))
       effective_address = g_strconcat ("http://", address, NULL);
   }
@@ -309,63 +316,35 @@ ephy_embed_utils_normalize_address (const char *address)
   return effective_address ? effective_address : g_strdup (address);
 }
 
+/* Searches @search_key with the default search engine. */
 char *
 ephy_embed_utils_autosearch_address (const char *search_key)
 {
-  char *query_param;
-  const char *address_search;
-  char *effective_address;
   EphyEmbedShell *shell;
-  EphySearchEngineManager *search_engine_manager;
+  EphySearchEngineManager *manager;
+  EphySearchEngine *engine;
 
   if (!g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_AUTOSEARCH))
     return g_strdup (search_key);
 
   shell = ephy_embed_shell_get_default ();
-  search_engine_manager = ephy_embed_shell_get_search_engine_manager (shell);
-  address_search = ephy_search_engine_manager_get_default_search_address (search_engine_manager);
+  manager = ephy_embed_shell_get_search_engine_manager (shell);
+  engine = ephy_search_engine_manager_get_default_engine (manager);
+  g_assert (engine != NULL);
 
-  query_param = soup_form_encode ("q", search_key, NULL);
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
-  /* Format string under control of user input... but gsettings is trusted input. */
-  /* + 2 here is getting rid of 'q=' */
-  effective_address = g_strdup_printf (address_search, query_param + 2);
-#pragma GCC diagnostic pop
-  g_free (query_param);
-
-  return effective_address;
-}
-
-static char *
-ensure_host_name_is_lowercase (const char *address)
-{
-  g_autofree gchar *host = ephy_string_get_host_name (address);
-  g_autofree gchar *lowercase_host = NULL;
-  char *ret = NULL;
-
-  if (host == NULL) {
-    return g_strdup (address);
-  }
-
-  lowercase_host = g_utf8_strdown (host, -1);
-
-  if (strcmp (host, lowercase_host) != 0) {
-    ret = ephy_string_find_and_replace (address, host, lowercase_host);
-  } else {
-    ret = g_strdup (address);
-  }
-
-  return ret;
+  return ephy_search_engine_build_search_address (engine, search_key);
 }
 
 char *
 ephy_embed_utils_normalize_or_autosearch_address (const char *address)
 {
-  g_autofree gchar *lower_case_address = ensure_host_name_is_lowercase (address);
+  EphySearchEngineManager *manager = ephy_embed_shell_get_search_engine_manager (ephy_embed_shell_get_default ());
+  char *bang_search = ephy_search_engine_manager_parse_bang_search (manager, address);
 
-  if (ephy_embed_utils_address_is_valid (lower_case_address))
-    return ephy_embed_utils_normalize_address (lower_case_address);
+  if (bang_search)
+    return bang_search;
+  else if (ephy_embed_utils_address_is_valid (address))
+    return ephy_embed_utils_normalize_address (address);
   else
     return ephy_embed_utils_autosearch_address (address);
 }
@@ -376,6 +355,7 @@ ephy_embed_utils_url_is_empty (const char *location)
   return (location == NULL ||
           location[0] == '\0' ||
           strcmp (location, "about:blank") == 0 ||
+          strcmp (location, "ephy-about:newtab") == 0 ||
           strcmp (location, "ephy-about:overview") == 0 ||
           strcmp (location, "ephy-about:incognito") == 0);
 }
@@ -384,6 +364,7 @@ ephy_embed_utils_url_is_empty (const char *location)
  * window's location entry. */
 static const char *do_not_show_address[] = {
   "about:blank",
+  "ephy-about:newtab",
   "ephy-about:incognito",
   "ephy-about:overview",
   NULL
@@ -401,9 +382,6 @@ ephy_embed_utils_is_no_show_address (const char *address)
     if (!strcmp (address, do_not_show_address[i]))
       return TRUE;
 
-  if (g_str_has_prefix (address, EPHY_VIEW_SOURCE_SCHEME))
-    return TRUE;
-
   return FALSE;
 }
 
@@ -414,8 +392,10 @@ ephy_embed_utils_get_title_from_address (const char *address)
     return g_strdup (address + 7);
 
   if (!strcmp (address, EPHY_ABOUT_SCHEME ":overview") ||
-      !strcmp (address, "about:overview"))
-    return g_strdup (_(OVERVIEW_PAGE_TITLE));
+      !strcmp (address, EPHY_ABOUT_SCHEME ":newtab") ||
+      !strcmp (address, "about:overview") ||
+      !strcmp (address, "about:newtab"))
+    return g_strdup (_(NEW_TAB_PAGE_TITLE));
 
   return ephy_string_get_host_name (address);
 }
