@@ -20,6 +20,7 @@
 
 #include "config.h"
 #include "ephy-web-process-extension.h"
+#include "ephy-webextension-api.h"
 
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
@@ -28,6 +29,7 @@
 #include "ephy-settings.h"
 #include "ephy-uri-helpers.h"
 #include "ephy-web-overview-model.h"
+#include "ephy-webextension-common.h"
 
 #include <gio/gio.h>
 #include <glib/gi18n.h>
@@ -36,13 +38,12 @@
 #include <jsc/jsc.h>
 #include <libsoup/soup.h>
 #include <string.h>
-#include <webkit2/webkit-web-extension.h>
-#include <JavaScriptCore/JavaScript.h>
+#include <webkit/webkit-web-process-extension.h>
 
 struct _EphyWebProcessExtension {
   GObject parent_instance;
 
-  WebKitWebExtension *extension;
+  WebKitWebProcessExtension *extension;
   gboolean initialized;
 
   GCancellable *cancellable;
@@ -51,45 +52,27 @@ struct _EphyWebProcessExtension {
   EphyPermissionsManager *permissions_manager;
 
   WebKitScriptWorld *script_world;
+  GHashTable *content_script_worlds;
 
   gboolean should_remember_passwords;
   gboolean is_private_profile;
 
   GHashTable *frames_map;
+  GHashTable *translation_table;
 };
 
-G_DEFINE_TYPE (EphyWebProcessExtension, ephy_web_process_extension, G_TYPE_OBJECT)
+G_DEFINE_FINAL_TYPE (EphyWebProcessExtension, ephy_web_process_extension, G_TYPE_OBJECT)
 
 static void
-web_page_will_submit_form (WebKitWebPage            *web_page,
-                           WebKitDOMHTMLFormElement *dom_form,
-                           WebKitFormSubmissionStep  step,
-                           WebKitFrame              *source_frame,
-                           WebKitFrame              *target_frame,
-                           GPtrArray                *text_field_names,
-                           GPtrArray                *text_field_values)
+web_page_will_submit_form (WebKitWebPage *web_page,
+                           JSCValue      *js_form,
+                           WebKitFrame   *source_frame,
+                           WebKitFrame   *target_frame)
 {
-  EphyWebProcessExtension *extension;
-  gboolean form_submit_handled;
-  g_autoptr (JSCContext) js_context = NULL;
   g_autoptr (JSCValue) js_ephy = NULL;
-  g_autoptr (JSCValue) js_form = NULL;
   g_autoptr (JSCValue) js_result = NULL;
 
-  form_submit_handled =
-    GPOINTER_TO_INT (g_object_get_data (G_OBJECT (dom_form),
-                                        "ephy-form-submit-handled"));
-  if (form_submit_handled)
-    return;
-
-  g_object_set_data (G_OBJECT (dom_form),
-                     "ephy-form-submit-handled",
-                     GINT_TO_POINTER (TRUE));
-
-  extension = ephy_web_process_extension_get ();
-  js_context = webkit_frame_get_js_context_for_script_world (source_frame, extension->script_world);
-  js_ephy = jsc_context_get_value (js_context, "Ephy");
-  js_form = webkit_frame_get_js_value_for_dom_object_in_script_world (source_frame, WEBKIT_DOM_OBJECT (dom_form), extension->script_world);
+  js_ephy = jsc_context_get_value (jsc_value_get_context (js_form), "Ephy");
   js_result = jsc_value_object_invoke_method (js_ephy,
                                               "handleFormSubmission",
                                               G_TYPE_UINT64, webkit_web_page_get_id (web_page),
@@ -135,29 +118,20 @@ frame_destroyed_notify (EphyWebProcessExtension *extension,
 }
 
 static void
-web_page_form_controls_associated (WebKitWebPage           *web_page,
-                                   GPtrArray               *elements,
-                                   WebKitFrame             *frame,
-                                   EphyWebProcessExtension *extension)
+web_page_form_controls_associated (WebKitWebPage *web_page,
+                                   WebKitFrame   *frame,
+                                   GPtrArray     *form_controls)
 {
-  g_autoptr (GPtrArray) form_controls = NULL;
+  EphyWebProcessExtension *extension;
   g_autoptr (JSCContext) js_context = NULL;
   g_autoptr (JSCValue) js_ephy = NULL;
   g_autoptr (JSCValue) js_serializer = NULL;
   g_autoptr (JSCValue) js_result = NULL;
   guint64 frame_id;
   guint64 *frame_id_copy;
-  guint i;
 
+  extension = ephy_web_process_extension_get ();
   js_context = webkit_frame_get_js_context_for_script_world (frame, extension->script_world);
-
-  form_controls = g_ptr_array_new_with_free_func (g_object_unref);
-  for (i = 0; i < elements->len; ++i) {
-    WebKitDOMObject *element = WEBKIT_DOM_OBJECT (g_ptr_array_index (elements, i));
-
-    g_ptr_array_add (form_controls, webkit_frame_get_js_value_for_dom_object_in_script_world (frame, element, extension->script_world));
-  }
-
   js_ephy = jsc_context_get_value (js_context, "Ephy");
   js_serializer = jsc_value_new_function (js_context,
                                           "passwordFormMessageSerializer",
@@ -190,6 +164,8 @@ web_page_context_menu (WebKitWebPage          *web_page,
 {
   EphyWebProcessExtension *extension;
   g_autofree char *string = NULL;
+  gboolean is_editable;
+  gboolean is_password;
   GVariantBuilder builder;
   WebKitFrame *frame;
   g_autoptr (JSCContext) js_context = NULL;
@@ -205,37 +181,151 @@ web_page_context_menu (WebKitWebPage          *web_page,
   js_value = jsc_context_evaluate (js_context, "window.getSelection().toString();", -1);
   if (!jsc_value_is_null (js_value) && !jsc_value_is_undefined (js_value))
     string = jsc_value_to_string (js_value);
+  g_object_unref (js_value);
 
-  if (!string || *string == '\0')
-    return FALSE;
+  js_value = jsc_context_evaluate (js_context, "contextMenuElementIsEditable;", -1);
+  is_editable = jsc_value_to_boolean (js_value);
+  g_object_unref (js_value);
+
+  js_value = jsc_context_evaluate (js_context, "contextMenuElementIsPassword;", -1);
+  is_password = jsc_value_to_boolean (js_value);
 
   g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
-  g_variant_builder_add (&builder, "{sv}", "SelectedText", g_variant_new_string (g_strstrip (string)));
+  g_variant_builder_add (&builder, "{sv}", "SelectedText", g_variant_new_string (string ? g_strstrip (string) : ""));
+  g_variant_builder_add (&builder, "{sv}", "IsEditable", g_variant_new_boolean (is_editable));
+  g_variant_builder_add (&builder, "{sv}", "IsPassword", g_variant_new_boolean (is_password));
   webkit_context_menu_set_user_data (context_menu,
                                      g_variant_builder_end (&builder));
 
   return TRUE;
 }
 
+static void
+content_script_window_object_cleared_cb (WebKitScriptWorld *world,
+                                         WebKitWebPage     *page,
+                                         WebKitFrame       *frame,
+                                         gpointer           user_data)
+{
+  EphyWebProcessExtension *extension = user_data;
+  g_autoptr (JSCContext) js_context = NULL;
+  g_autoptr (JSCValue) js_browser = NULL;
+  g_autoptr (JSCValue) result = NULL;
+  g_autoptr (GBytes) bytes = NULL;
+  JsonObject *translations;
+  const char *guid;
+  const char *data;
+  gsize data_size;
+
+  guid = webkit_script_world_get_name (world);
+  js_context = webkit_frame_get_js_context_for_script_world (frame, world);
+  translations = g_hash_table_lookup (extension->translation_table, guid);
+
+  js_browser = jsc_context_get_value (js_context, "browser");
+  g_assert (!jsc_value_is_object (js_browser));
+
+  bytes = g_resources_lookup_data ("/org/gnome/epiphany-web-extension/js/webextensions-common.js", G_RESOURCE_LOOKUP_FLAGS_NONE, NULL);
+  data = g_bytes_get_data (bytes, &data_size);
+  result = jsc_context_evaluate_with_source_uri (js_context, data, data_size, "resource:///org/gnome/epiphany-web-extension/js/webextensions-common.js", 1);
+  g_clear_object (&result);
+
+  ephy_webextension_install_common_apis (page,
+                                         frame,
+                                         js_context,
+                                         guid,
+                                         translations);
+}
+
+static void
+create_content_script_world (EphyWebProcessExtension *extension,
+                             const char              *guid)
+{
+  WebKitScriptWorld *world = webkit_script_world_new_with_name (guid);
+
+  g_hash_table_insert (extension->content_script_worlds, g_strdup (guid), world);
+
+  g_signal_connect (world,
+                    "window-object-cleared",
+                    G_CALLBACK (content_script_window_object_cleared_cb),
+                    extension);
+}
+
+static gboolean
+web_page_received_message (WebKitWebPage     *web_page,
+                           WebKitUserMessage *message,
+                           gpointer           user_data)
+{
+  EphyWebProcessExtension *extension = user_data;
+  const char *name = webkit_user_message_get_name (message);
+
+  if (g_strcmp0 (name, "WebExtension.Initialize") == 0) {
+    GVariant *parameters;
+    const char *guid;
+
+    parameters = webkit_user_message_get_parameters (message);
+    if (!parameters)
+      return FALSE;
+
+    g_variant_get (parameters, "&s", &guid);
+    create_content_script_world (extension, guid);
+  } else {
+    g_warning ("Unhandled page message: %s", name);
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
 static void
 ephy_web_process_extension_page_created_cb (EphyWebProcessExtension *extension,
                                             WebKitWebPage           *web_page)
 {
-  g_autoptr (JSCContext) js_context = NULL;
-
-  /* Enforce the creation of the script world global context in the main frame */
-  js_context = webkit_frame_get_js_context_for_script_world (webkit_web_page_get_main_frame (web_page), extension->script_world);
-  (void)js_context;
+  WebKitWebFormManager *form_manager;
 
   g_signal_connect (web_page, "context-menu",
                     G_CALLBACK (web_page_context_menu),
                     extension);
-  g_signal_connect (web_page, "will-submit-form",
-                    G_CALLBACK (web_page_will_submit_form),
-                    extension);
-  g_signal_connect (web_page, "form-controls-associated-for-frame",
-                    G_CALLBACK (web_page_form_controls_associated),
+  g_signal_connect (web_page, "user-message-received",
+                    G_CALLBACK (web_page_received_message),
                     extension);
+
+  form_manager = webkit_web_page_get_form_manager (web_page, extension->script_world);
+  g_signal_connect_swapped (form_manager, "will-send-submit-event",
+                            G_CALLBACK (web_page_will_submit_form),
+                            web_page);
+  g_signal_connect_swapped (form_manager, "will-submit-form",
+                            G_CALLBACK (web_page_will_submit_form),
+                            web_page);
+  g_signal_connect_swapped (form_manager, "form-controls-associated",
+                            G_CALLBACK (web_page_form_controls_associated),
+                            web_page);
+}
+
+static void
+ephy_web_process_extension_add_translations (GHashTable *translation_table,
+                                             const char *guid,
+                                             const char *data)
+{
+  g_autoptr (JsonParser) parser = NULL;
+  JsonNode *root;
+  JsonObject *root_object;
+  g_autoptr (GError) error = NULL;
+
+  g_hash_table_remove (translation_table, guid);
+
+  if (!data || !*data)
+    return;
+
+  parser = json_parser_new ();
+  if (json_parser_load_from_data (parser, data, -1, &error)) {
+    root = json_parser_get_root (parser);
+    g_assert (root);
+    root_object = json_node_get_object (root);
+    g_assert (root_object);
+
+    g_hash_table_insert (translation_table, g_strdup (guid), json_object_ref (root_object));
+  } else {
+    g_warning ("Could not read translation json data: %s. '%s'", error->message, data);
+  }
 }
 
 static void
@@ -326,6 +416,17 @@ ephy_web_process_extension_user_message_received_cb (EphyWebProcessExtension *ex
       return;
 
     g_variant_get (parameters, "b", &extension->should_remember_passwords);
+  } else if (g_strcmp0 (name, "WebExtension.UpdateTranslations") == 0) {
+    GVariant *parameters;
+    const char *guid;
+    const char *data;
+
+    parameters = webkit_user_message_get_parameters (message);
+    if (!parameters)
+      return;
+
+    g_variant_get (parameters, "(&s&s)", &guid, &data);
+    ephy_web_process_extension_add_translations (extension->translation_table, guid, data);
   }
 }
 
@@ -376,6 +477,9 @@ ephy_web_process_extension_dispose (GObject *object)
     g_clear_pointer (&extension->frames_map, g_hash_table_unref);
   }
 
+  g_clear_pointer (&extension->translation_table, g_hash_table_destroy);
+  g_clear_pointer (&extension->content_script_worlds, g_hash_table_destroy);
+
   G_OBJECT_CLASS (ephy_web_process_extension_parent_class)->dispose (object);
 }
 
@@ -423,14 +527,7 @@ static void
 js_auto_fill (JSCValue   *js_element,
               const char *value)
 {
-  WebKitDOMNode *node;
-  WebKitDOMElement *element;
-
-  node = webkit_dom_node_for_js_value (js_element);
-  element = WEBKIT_DOM_ELEMENT (node);
-
-  webkit_dom_element_html_input_element_set_auto_filled (element, TRUE);
-  webkit_dom_element_html_input_element_set_editing_value (element, value);
+  webkit_web_form_manager_input_element_auto_fill (js_element, value);
 }
 
 typedef struct {
@@ -494,7 +591,7 @@ js_query_usernames (const char              *origin,
   if (!origin)
     return;
 
-  web_page = webkit_web_extension_get_page (extension->extension, page_id);
+  web_page = webkit_web_process_extension_get_page (extension->extension, page_id);
   if (!web_page)
     return;
 
@@ -570,7 +667,7 @@ js_query_password (const char              *origin,
   if (!origin || !target_origin || !password_field)
     return;
 
-  web_page = webkit_web_extension_get_page (extension->extension, page_id);
+  web_page = webkit_web_process_extension_get_page (extension->extension, page_id);
   if (!web_page)
     return;
 
@@ -595,9 +692,7 @@ js_is_web_application (void)
 static gboolean
 js_is_edited (JSCValue *js_element)
 {
-  WebKitDOMNode *node = webkit_dom_node_for_js_value (js_element);
-
-  return webkit_dom_element_html_input_element_is_user_edited (WEBKIT_DOM_ELEMENT (node));
+  return webkit_web_form_manager_input_element_is_user_edited (js_element);
 }
 
 static gboolean
@@ -645,6 +740,10 @@ window_object_cleared_cb (WebKitScriptWorld       *world,
   js_context = webkit_frame_get_js_context_for_script_world (frame, world);
   jsc_context_push_exception_handler (js_context, (JSCExceptionHandler)js_exception_handler, NULL, NULL);
 
+  result = jsc_context_get_value (js_context, "Ephy");
+  g_assert (jsc_value_is_undefined (result));
+  g_clear_object (&result);
+
   bytes = g_resources_lookup_data ("/org/gnome/epiphany-web-process-extension/js/ephy.js", G_RESOURCE_LOOKUP_FLAGS_NONE, NULL);
   data = g_bytes_get_data (bytes, &data_size);
   result = jsc_context_evaluate_with_source_uri (js_context, data, data_size, "resource:///org/gnome/epiphany-web-process-extension/js/ephy.js", 1);
@@ -758,11 +857,11 @@ window_object_cleared_cb (WebKitScriptWorld       *world,
 }
 
 void
-ephy_web_process_extension_initialize (EphyWebProcessExtension *extension,
-                                       WebKitWebExtension      *wk_extension,
-                                       const char              *guid,
-                                       gboolean                 should_remember_passwords,
-                                       gboolean                 is_private_profile)
+ephy_web_process_extension_initialize (EphyWebProcessExtension   *extension,
+                                       WebKitWebProcessExtension *wk_extension,
+                                       const char                *guid,
+                                       gboolean                   should_remember_passwords,
+                                       gboolean                   is_private_profile)
 {
   g_assert (EPHY_IS_WEB_PROCESS_EXTENSION (extension));
 
@@ -771,7 +870,10 @@ ephy_web_process_extension_initialize (EphyWebProcessExtension *extension,
 
   extension->initialized = TRUE;
 
+  g_assert (guid && *guid);
+
   extension->script_world = webkit_script_world_new_with_name (guid);
+
   g_signal_connect (extension->script_world,
                     "window-object-cleared",
                     G_CALLBACK (window_object_cleared_cb),
@@ -793,4 +895,10 @@ ephy_web_process_extension_initialize (EphyWebProcessExtension *extension,
 
   extension->frames_map = g_hash_table_new_full (g_int64_hash, g_int64_equal,
                                                  g_free, NULL);
+
+  extension->translation_table = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                                        g_free, (GDestroyNotify)json_object_unref);
+
+  extension->content_script_worlds = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                                            g_free, g_object_unref);
 }
