@@ -314,7 +314,7 @@ ephy_profile_dir_is_default (void)
 /**
  * ephy_profile_dir_is_web_application:
  *
- * Returns whether the profile directory in use is a web appplication one.
+ * Returns whether the profile directory in use is a web application one.
  *
  * Returns: %TRUE if it is a web application profile dir, %FALSE for others
  */
@@ -580,14 +580,11 @@ launch_application (GAppInfo *app,
   g_autoptr (GdkAppLaunchContext) context = NULL;
   g_autoptr (GError) error = NULL;
   GdkDisplay *display;
-  GdkScreen *screen;
   gboolean res;
 
   display = gdk_display_get_default ();
-  screen = gdk_screen_get_default ();
 
   context = gdk_display_get_app_launch_context (display);
-  gdk_app_launch_context_set_screen (context, screen);
 
   res = g_app_info_launch (app, files,
                            G_APP_LAUNCH_CONTEXT (context), &error);
@@ -623,18 +620,19 @@ launch_via_uri_handler (GFile *file)
  * ephy_file_launch_handler:
  * @file: a #GFile to pass as argument
  *
- * Launches @file with its default handler application, if @mime_type is %NULL
- * then @file will be queried for its type.
+ * If @mime_type is %NULL, launches @file with its default handler application.
+ * Otherwise, launches @file will the default handler for @mime_type.
  *
  * Returns: %TRUE on success
  **/
 gboolean
-ephy_file_launch_handler (GFile *file)
+ephy_file_launch_uri_handler (GFile      *file,
+                              const char *mime_type)
 {
-  GAppInfo *app = NULL;
-  gboolean ret = FALSE;
+  g_autoptr (GAppInfo) app = NULL;
   g_autoptr (GList) list = NULL;
   g_autoptr (GError) error = NULL;
+  gboolean ret = FALSE;
 
   g_assert (file != NULL);
 
@@ -645,7 +643,11 @@ ephy_file_launch_handler (GFile *file)
   if (ephy_is_running_inside_sandbox ())
     return launch_via_uri_handler (file);
 
-  app = g_file_query_default_handler (file, NULL, &error);
+  if (mime_type)
+    app = g_app_info_get_default_for_type (mime_type, TRUE);
+  if (!app)
+    app = g_file_query_default_handler (file, NULL, &error);
+
   if (!app) {
     g_autofree char *path = g_file_get_path (file);
     g_warning ("No available application to open %s: %s", path, error->message);
@@ -661,15 +663,14 @@ ephy_file_launch_handler (GFile *file)
 static gboolean
 open_in_default_handler (const char *uri,
                          const char *mime_type,
-                         GdkScreen  *screen)
+                         GdkDisplay *display)
 {
   g_autoptr (GdkAppLaunchContext) context = NULL;
   g_autoptr (GAppInfo) appinfo = NULL;
   g_autoptr (GError) error = NULL;
   GList uris;
 
-  context = gdk_display_get_app_launch_context (screen ? gdk_screen_get_display (screen) : gdk_display_get_default ());
-  gdk_app_launch_context_set_screen (context, screen);
+  context = gdk_display_get_app_launch_context (display ? display : gdk_display_get_default ());
 
   appinfo = g_app_info_get_default_for_type (mime_type, TRUE);
   if (!appinfo) {
@@ -690,13 +691,13 @@ open_in_default_handler (const char *uri,
 
 gboolean
 ephy_file_open_uri_in_default_browser (const char *uri,
-                                       GdkScreen  *screen)
+                                       GdkDisplay *display)
 {
   if (ephy_is_running_inside_sandbox ()) {
     ephy_open_uri_via_flatpak_portal (uri);
     return TRUE;
   }
-  return open_in_default_handler (uri, "x-scheme-handler/http", screen);
+  return open_in_default_handler (uri, "x-scheme-handler/http", display);
 }
 
 /**
@@ -758,7 +759,7 @@ ephy_file_delete_dir_recursively (const char  *directory,
 
         g_set_error (error, G_IO_ERROR,
                      g_io_error_from_errno (errsv),
-                     "Error removing file %s: %s",
+                     _("Error removing file %s: %s"),
                      file_path, g_strerror (errsv));
         failed = TRUE;
       }
@@ -776,7 +777,7 @@ ephy_file_delete_dir_recursively (const char  *directory,
 
       g_set_error (error, G_IO_ERROR,
                    g_io_error_from_errno (errsv),
-                   "Error removing directory %s: %s",
+                   _("Error removing directory %s: %s"),
                    directory, g_strerror (errsv));
       failed = TRUE;
     }
