@@ -46,6 +46,18 @@ G_DECLARE_FINAL_TYPE (EphyPasswordManager, ephy_password_manager, EPHY, PASSWORD
 
 typedef void (*EphyPasswordManagerQueryCallback) (GList *records, gpointer user_data);
 
+typedef struct {
+  char *origin;
+  char *target_origin;
+  char *username;
+  char *password;
+  char *usernameField;
+  char *passwordField;
+  gboolean isNew;
+} EphyPasswordRequestData;
+
+void                 ephy_password_request_data_free                (EphyPasswordRequestData *request_data);
+
 EphyPasswordManager *ephy_password_manager_new                      (void);
 GList               *ephy_password_manager_get_usernames_for_origin (EphyPasswordManager *self,
                                                                      const char          *origin);
@@ -81,8 +93,5 @@ gboolean             ephy_password_manager_forget_finish             (EphyPasswo
                                                                       GAsyncResult         *result,
                                                                       GError              **error);
 void                 ephy_password_manager_forget_all                (EphyPasswordManager *self);
-void                 ephy_password_manager_export_to_js_context      (EphyPasswordManager *self,
-                                                                      JSCContext          *js_context,
-                                                                      JSCValue            *js_namespace);
 
 G_END_DECLS
