@@ -21,8 +21,6 @@
 
 #include "ephy-action-bar.h"
 #include "ephy-add-bookmark-popover.h"
-#include "ephy-location-entry.h"
-#include "ephy-pages-button.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
 #include "ephy-tab-view.h"
@@ -30,26 +28,22 @@
 enum {
   PROP_0,
   PROP_WINDOW,
-  PROP_CAN_REVEAL,
   N_PROPERTIES
 };
 
 static GParamSpec *object_properties[N_PROPERTIES] = { NULL, };
 
 struct _EphyActionBar {
-  GtkBin parent_instance;
+  AdwBin parent_instance;
 
   EphyWindow *window;
-  GtkRevealer *revealer;
+  GtkWidget *toolbar;
   EphyActionBarStart *action_bar_start;
   EphyActionBarEnd *action_bar_end;
-  EphyPagesButton *pages_button;
-
-  EphyAdaptiveMode adaptive_mode;
-  gboolean can_reveal;
+  AdwTabButton *tab_button;
 };
 
-G_DEFINE_TYPE (EphyActionBar, ephy_action_bar, GTK_TYPE_BIN)
+G_DEFINE_FINAL_TYPE (EphyActionBar, ephy_action_bar, ADW_TYPE_BIN)
 
 static void
 sync_chromes_visibility (EphyActionBar *action_bar)
@@ -64,18 +58,6 @@ sync_chromes_visibility (EphyActionBar *action_bar)
                                                  chrome & EPHY_WINDOW_CHROME_BOOKMARKS);
 }
 
-static void
-update_revealer (EphyActionBar *action_bar)
-{
-  gboolean reveal = action_bar->can_reveal &&
-                    (action_bar->adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW);
-
-  if (reveal)
-    gtk_widget_show (GTK_WIDGET (action_bar));
-
-  gtk_revealer_set_reveal_child (action_bar->revealer, reveal);
-}
-
 static void
 ephy_action_bar_set_property (GObject      *object,
                               guint         property_id,
@@ -89,10 +71,6 @@ ephy_action_bar_set_property (GObject      *object,
       action_bar->window = EPHY_WINDOW (g_value_get_object (value));
       g_object_notify_by_pspec (object, object_properties[PROP_WINDOW]);
       break;
-    case PROP_CAN_REVEAL:
-      action_bar->can_reveal = g_value_get_boolean (value);
-      update_revealer (action_bar);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -110,9 +88,6 @@ ephy_action_bar_get_property (GObject    *object,
     case PROP_WINDOW:
       g_value_set_object (value, action_bar->window);
       break;
-    case PROP_CAN_REVEAL:
-      g_value_set_boolean (value, action_bar->can_reveal);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -132,9 +107,8 @@ ephy_action_bar_constructed (GObject *object)
                            G_CALLBACK (sync_chromes_visibility), action_bar,
                            G_CONNECT_SWAPPED);
 
-  g_object_bind_property (view, "n-pages",
-                          action_bar->pages_button, "n-pages",
-                          G_BINDING_SYNC_CREATE);
+  adw_tab_button_set_view (action_bar->tab_button,
+                           ephy_tab_view_get_tab_view (view));
 }
 
 static void
@@ -149,18 +123,10 @@ ephy_action_bar_class_init (EphyActionBarClass *klass)
 
   object_properties[PROP_WINDOW] =
     g_param_spec_object ("window",
-                         "Window",
-                         "The action_bar's EphyWindow",
+                         NULL, NULL,
                          EPHY_TYPE_WINDOW,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
-  object_properties[PROP_CAN_REVEAL] =
-    g_param_spec_boolean ("can-reveal",
-                          "Can Reveal",
-                          "Whether the action bar can be revealed",
-                          TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-
   g_object_class_install_properties (gobject_class,
                                      N_PROPERTIES,
                                      object_properties);
@@ -168,15 +134,12 @@ ephy_action_bar_class_init (EphyActionBarClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/epiphany/gtk/action-bar.ui");
 
-  gtk_widget_class_bind_template_child (widget_class,
-                                        EphyActionBar,
-                                        revealer);
   gtk_widget_class_bind_template_child (widget_class,
                                         EphyActionBar,
                                         action_bar_start);
   gtk_widget_class_bind_template_child (widget_class,
                                         EphyActionBar,
-                                        pages_button);
+                                        tab_button);
   gtk_widget_class_bind_template_child (widget_class,
                                         EphyActionBar,
                                         action_bar_end);
@@ -190,23 +153,17 @@ ephy_action_bar_init (EphyActionBar *action_bar)
   /* Ensure the types used by the template have been initialized. */
   EPHY_TYPE_ACTION_BAR_END;
   EPHY_TYPE_ACTION_BAR_START;
-  EPHY_TYPE_PAGES_BUTTON;
 
   gtk_widget_init_template (GTK_WIDGET (action_bar));
 
   mode = ephy_embed_shell_get_mode (EPHY_EMBED_SHELL (ephy_shell_get_default ()));
-  gtk_widget_set_visible (GTK_WIDGET (action_bar->pages_button),
+  gtk_widget_set_visible (GTK_WIDGET (action_bar->tab_button),
                           mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
 
   ephy_action_bar_start_set_adaptive_mode (action_bar->action_bar_start,
                                            EPHY_ADAPTIVE_MODE_NARROW);
-
-  g_object_bind_property (action_bar->revealer, "child-revealed",
-                          action_bar, "visible",
-                          G_BINDING_DEFAULT);
-
-  action_bar->can_reveal = true;
-  update_revealer (action_bar);
+  ephy_action_bar_end_set_adaptive_mode (action_bar->action_bar_end,
+                                         EPHY_ADAPTIVE_MODE_NARROW);
 }
 
 EphyActionBar *
@@ -228,17 +185,3 @@ ephy_action_bar_get_action_bar_end (EphyActionBar *action_bar)
 {
   return action_bar->action_bar_end;
 }
-
-void
-ephy_action_bar_set_adaptive_mode (EphyActionBar    *action_bar,
-                                   EphyAdaptiveMode  adaptive_mode)
-{
-  EphyEmbedShellMode mode = ephy_embed_shell_get_mode (ephy_embed_shell_get_default ());
-
-  action_bar->adaptive_mode = adaptive_mode;
-  ephy_action_bar_end_set_show_bookmark_button (action_bar->action_bar_end,
-                                                adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW &&
-                                                mode != EPHY_EMBED_SHELL_MODE_APPLICATION);
-
-  update_revealer (action_bar);
-}
