@@ -35,8 +35,8 @@
 #include "ephy-title-widget.h"
 #include "ephy-type-builtins.h"
 
+#include <adwaita.h>
 #include <glib/gi18n.h>
-#include <handy.h>
 
 #define POPOVER_HIDE_DELAY 300
 
@@ -52,26 +52,23 @@ static GParamSpec *object_properties[N_PROPERTIES] = { NULL, };
 static const char *REFRESH_BUTTON_TOOLTIP = N_("Reload the current page");
 
 struct _EphyHeaderBar {
-  GtkBin parent_instance;
+  AdwBin parent_instance;
 
   GtkWidget *header_bar;
   EphyWindow *window;
   EphyTitleWidget *title_widget;
-  GtkRevealer *start_revealer;
-  GtkRevealer *end_revealer;
   EphyActionBarStart *action_bar_start;
   EphyActionBarEnd *action_bar_end;
   GtkWidget *page_menu_button;
   GtkWidget *zoom_level_label;
   GtkWidget *restore_button;
   GtkWidget *combined_stop_reload_button;
-  GtkWidget *combined_stop_reload_image;
   GtkWidget *page_menu_popover;
 
   guint popover_hide_timeout_id;
 };
 
-G_DEFINE_TYPE (EphyHeaderBar, ephy_header_bar, GTK_TYPE_BIN)
+G_DEFINE_FINAL_TYPE (EphyHeaderBar, ephy_header_bar, ADW_TYPE_BIN)
 
 static void
 ephy_header_bar_set_property (GObject      *object,
@@ -122,14 +119,12 @@ sync_chromes_visibility (EphyHeaderBar *header_bar)
   gtk_widget_set_visible (header_bar->page_menu_button, chrome & EPHY_WINDOW_CHROME_MENU);
 }
 
-static gboolean
+static void
 hide_timeout_cb (EphyHeaderBar *header_bar)
 {
-  gtk_popover_popdown (GTK_POPOVER (header_bar->page_menu_popover));
+  gtk_menu_button_popdown (GTK_MENU_BUTTON (header_bar->page_menu_button));
 
   header_bar->popover_hide_timeout_id = 0;
-
-  return G_SOURCE_REMOVE;
 }
 
 void
@@ -137,25 +132,69 @@ fullscreen_changed_cb (EphyHeaderBar *header_bar)
 {
   gboolean fullscreen;
 
-  g_object_get (header_bar->window, "fullscreen", &fullscreen, NULL);
+  g_object_get (header_bar->window, "fullscreened", &fullscreen, NULL);
 
-  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar->header_bar), !fullscreen);
+  adw_header_bar_set_show_start_title_buttons (ADW_HEADER_BAR (header_bar->header_bar), !fullscreen);
+  adw_header_bar_set_show_end_title_buttons (ADW_HEADER_BAR (header_bar->header_bar), !fullscreen);
   gtk_widget_set_visible (header_bar->restore_button, fullscreen);
 
   if (fullscreen) {
     g_clear_handle_id (&header_bar->popover_hide_timeout_id, g_source_remove);
 
     header_bar->popover_hide_timeout_id =
-      g_timeout_add (POPOVER_HIDE_DELAY, (GSourceFunc)hide_timeout_cb, header_bar);
+      g_timeout_add_once (POPOVER_HIDE_DELAY, (GSourceOnceFunc)hide_timeout_cb, header_bar);
   }
 }
 
-static void
-update_revealer_visibility (GtkRevealer *revealer)
+static gboolean
+remove_menu_item (GMenu      *menu,
+                  const char *action_name)
 {
-  gtk_widget_set_visible (GTK_WIDGET (revealer),
-                          gtk_revealer_get_reveal_child (revealer) ||
-                          gtk_revealer_get_child_revealed (revealer));
+  int i, n;
+
+  n = g_menu_model_get_n_items (G_MENU_MODEL (menu));
+
+  for (i = 0; i < n; i++) {
+    g_autofree char *item_action = NULL;
+    g_autofree char *submenu_id = NULL;
+    g_autoptr (GMenuModel) section = NULL;
+
+    g_menu_model_get_item_attribute (G_MENU_MODEL (menu),
+                                     i,
+                                     G_MENU_ATTRIBUTE_ACTION,
+                                     "s",
+                                     &item_action);
+
+    if (!g_strcmp0 (action_name, item_action)) {
+      g_menu_remove (menu, i);
+      return TRUE;
+    }
+
+    /* FIXME: this isn't particularly great. Maybe we should have custom
+     * attributes for everything like show-in-app-mode etc? */
+    g_menu_model_get_item_attribute (G_MENU_MODEL (menu),
+                                     i,
+                                     "ephy-submenu-id",
+                                     "s",
+                                     &submenu_id);
+
+    if (!g_strcmp0 (action_name, submenu_id)) {
+      g_menu_remove (menu, i);
+      return TRUE;
+    }
+
+    section = g_menu_model_get_item_link (G_MENU_MODEL (menu),
+                                          i,
+                                          G_MENU_LINK_SECTION);
+
+    if (!G_IS_MENU (section))
+      continue;
+
+    if (remove_menu_item (G_MENU (section), action_name))
+      return TRUE;
+  }
+
+  return FALSE;
 }
 
 static void
@@ -167,49 +206,36 @@ ephy_header_bar_constructed (GObject *object)
   GtkBuilder *builder;
   EphyEmbedShell *embed_shell;
   GtkSizeGroup *downloads_size_group;
+  GMenu *menu;
 
   G_OBJECT_CLASS (ephy_header_bar_parent_class)->constructed (object);
 
   g_signal_connect_object (header_bar->window, "notify::chrome",
                            G_CALLBACK (sync_chromes_visibility), header_bar,
                            G_CONNECT_SWAPPED);
-  g_signal_connect_object (header_bar->window, "notify::fullscreen",
+  g_signal_connect_object (header_bar->window, "notify::fullscreened",
                            G_CALLBACK (fullscreen_changed_cb), header_bar,
                            G_CONNECT_SWAPPED);
 
   /* Header bar */
-  header_bar->header_bar = gtk_header_bar_new ();
-  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (header_bar->header_bar), TRUE);
-  gtk_widget_show (header_bar->header_bar);
-  gtk_container_add (GTK_CONTAINER (header_bar), header_bar->header_bar);
+  header_bar->header_bar = adw_header_bar_new ();
+  adw_bin_set_child (ADW_BIN (header_bar), header_bar->header_bar);
 
   /* Start action elements */
   header_bar->action_bar_start = ephy_action_bar_start_new ();
-  gtk_widget_show (GTK_WIDGET (header_bar->action_bar_start));
-  header_bar->start_revealer = GTK_REVEALER (gtk_revealer_new ());
-  g_signal_connect (header_bar->start_revealer, "notify::child-revealed",
-                    G_CALLBACK (update_revealer_visibility), NULL);
-  g_signal_connect (header_bar->start_revealer, "notify::reveal-child",
-                    G_CALLBACK (update_revealer_visibility), NULL);
-  gtk_revealer_set_transition_type (GTK_REVEALER (header_bar->start_revealer), GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT);
-  gtk_container_add (GTK_CONTAINER (header_bar->start_revealer), GTK_WIDGET (header_bar->action_bar_start));
-
-  gtk_header_bar_pack_start (GTK_HEADER_BAR (header_bar->header_bar),
-                             GTK_WIDGET (header_bar->start_revealer));
+  adw_header_bar_pack_start (ADW_HEADER_BAR (header_bar->header_bar),
+                             GTK_WIDGET (header_bar->action_bar_start));
 
   embed_shell = ephy_embed_shell_get_default ();
 
   /* Title widget (location entry or title box) */
   if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_APPLICATION)
     header_bar->title_widget = EPHY_TITLE_WIDGET (ephy_title_box_new ());
-  else {
+  else
     header_bar->title_widget = EPHY_TITLE_WIDGET (ephy_location_entry_new ());
-  }
 
-  event_box = gtk_event_box_new ();
-  gtk_widget_add_events (event_box, GDK_ALL_EVENTS_MASK);
-  gtk_widget_show (event_box);
-  gtk_header_bar_set_custom_title (GTK_HEADER_BAR (header_bar->header_bar), event_box);
+  event_box = adw_bin_new ();
+  adw_header_bar_set_title_widget (ADW_HEADER_BAR (header_bar->header_bar), event_box);
   gtk_widget_set_name (event_box, "title-box-container");
 
   if (is_desktop_pantheon ()) {
@@ -218,22 +244,19 @@ ephy_header_bar_constructed (GObject *object)
     gtk_widget_set_margin_start (GTK_WIDGET (header_bar->title_widget), 6);
     gtk_widget_set_margin_end (GTK_WIDGET (header_bar->title_widget), 6);
 
-    gtk_container_add (GTK_CONTAINER (event_box), GTK_WIDGET (header_bar->title_widget));
+    adw_bin_set_child (ADW_BIN (event_box), GTK_WIDGET (header_bar->title_widget));
   } else {
     GtkWidget *clamp;
 
-    clamp = hdy_clamp_new ();
+    clamp = adw_clamp_new ();
     gtk_widget_set_hexpand (GTK_WIDGET (clamp), TRUE);
-    gtk_widget_show (clamp);
-    hdy_clamp_set_maximum_size (HDY_CLAMP (clamp), 860);
-    hdy_clamp_set_tightening_threshold (HDY_CLAMP (clamp), 560);
-    gtk_container_add (GTK_CONTAINER (clamp), GTK_WIDGET (header_bar->title_widget));
+    adw_clamp_set_maximum_size (ADW_CLAMP (clamp), 860);
+    adw_clamp_set_tightening_threshold (ADW_CLAMP (clamp), 560);
+    adw_clamp_set_child (ADW_CLAMP (clamp), GTK_WIDGET (header_bar->title_widget));
 
-    gtk_container_add (GTK_CONTAINER (event_box), clamp);
+    adw_bin_set_child (ADW_BIN (event_box), clamp);
   }
 
-  gtk_widget_show (GTK_WIDGET (header_bar->title_widget));
-
   if (EPHY_IS_LOCATION_ENTRY (header_bar->title_widget)) {
     EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (header_bar->title_widget);
     GtkWidget *popover = ephy_add_bookmark_popover_new ();
@@ -242,85 +265,72 @@ ephy_header_bar_constructed (GObject *object)
   }
 
   /* Fullscreen restore button */
-  header_bar->restore_button = gtk_button_new_from_icon_name ("view-restore-symbolic",
-                                                              GTK_ICON_SIZE_BUTTON);
+  header_bar->restore_button = gtk_button_new_from_icon_name ("view-restore-symbolic");
+  gtk_widget_set_visible (header_bar->restore_button, FALSE);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (header_bar->restore_button),
                                   "win.fullscreen");
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar),
+  adw_header_bar_pack_end (ADW_HEADER_BAR (header_bar->header_bar),
                            GTK_WIDGET (header_bar->restore_button));
 
   /* Page Menu */
   button = gtk_menu_button_new ();
   header_bar->page_menu_button = button;
-  gtk_button_set_image (GTK_BUTTON (button),
-                        gtk_image_new_from_icon_name ("open-menu-symbolic", GTK_ICON_SIZE_BUTTON));
-  g_type_ensure (G_TYPE_THEMED_ICON);
+  gtk_menu_button_set_icon_name (GTK_MENU_BUTTON (button), "open-menu-symbolic");
+  gtk_widget_set_tooltip_text (button, _("Main Menu"));
   builder = gtk_builder_new_from_resource ("/org/gnome/epiphany/gtk/page-menu-popover.ui");
+  menu = G_MENU (gtk_builder_get_object (builder, "menu"));
   header_bar->page_menu_popover = GTK_WIDGET (gtk_builder_get_object (builder, "page-menu-popover"));
   header_bar->zoom_level_label = GTK_WIDGET (gtk_builder_get_object (builder, "zoom-level"));
+
   if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_APPLICATION) {
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-window-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "new-incognito-window-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "reopen-closed-tab-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "application-manager-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "override-text-encoding-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "override-text-encoding-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "keyboard-shortcuts-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "help-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "firefox-sync-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "firefox-sync-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "import-export-menu")));
+    remove_menu_item (menu, "app.new-incognito");
+    remove_menu_item (menu, "app.reopen-closed-tab");
+    remove_menu_item (menu, "win.save-as-application");
+    remove_menu_item (menu, "win.open-application-manager");
+    remove_menu_item (menu, "win.encoding");
+    remove_menu_item (menu, "app.shortcuts");
+    remove_menu_item (menu, "app.help");
+    remove_menu_item (menu, "app.firefox-sync-dialog");
+    remove_menu_item (menu, "import-export");
   } else if (ephy_is_running_inside_sandbox ()) {
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-button")));
+    remove_menu_item (menu, "app.run-in-background");
 
     if (is_desktop_pantheon ())
-      gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "help-button")));
+      remove_menu_item (menu, "app.help");
   } else {
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "run-in-background-button")));
+    remove_menu_item (menu, "app.run-in-background");
   }
 
   if (!ephy_can_install_web_apps ()) {
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-separator")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "save-as-application-button")));
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "application-manager-button")));
+    remove_menu_item (menu, "win.save-as-application");
+    remove_menu_item (menu, "win.open-application-manager");
   }
 
   header_bar->combined_stop_reload_button = GTK_WIDGET (gtk_builder_get_object (builder, "combined_stop_reload_button"));
-  header_bar->combined_stop_reload_image = GTK_WIDGET (gtk_builder_get_object (builder, "combined_stop_reload_image"));
   gtk_widget_set_tooltip_text (header_bar->combined_stop_reload_button, _(REFRESH_BUTTON_TOOLTIP));
 
   if (is_desktop_pantheon ()) {
-    gtk_widget_destroy (GTK_WIDGET (gtk_builder_get_object (builder, "about-button")));
+    GtkWidget *button_box;
 
-    gtk_button_set_image (GTK_BUTTON (button),
-                          gtk_image_new_from_icon_name ("open-menu",
-                                                        GTK_ICON_SIZE_LARGE_TOOLBAR));
+    remove_menu_item (menu, "app.about");
+
+    gtk_menu_button_set_icon_name (GTK_MENU_BUTTON (button), "open-menu");
+    gtk_widget_add_css_class (button, "toolbar-button");
+
+    button_box = GTK_WIDGET (gtk_builder_get_object (builder, "button-box"));
+    gtk_widget_add_css_class (button_box, "linked");
+    gtk_box_set_spacing (GTK_BOX (button_box), 0);
   }
-  g_settings_bind (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_WEBEXTENSIONS, gtk_builder_get_object (builder, "extensions-button"), "visible", G_SETTINGS_BIND_DEFAULT);
 
   gtk_menu_button_set_popover (GTK_MENU_BUTTON (button), header_bar->page_menu_popover);
   g_object_unref (builder);
 
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar), button);
+  adw_header_bar_pack_end (ADW_HEADER_BAR (header_bar->header_bar), button);
 
   /* End action elements */
   header_bar->action_bar_end = ephy_action_bar_end_new ();
-  gtk_widget_show (GTK_WIDGET (header_bar->action_bar_end));
-  header_bar->end_revealer = GTK_REVEALER (gtk_revealer_new ());
-  g_signal_connect (header_bar->end_revealer, "notify::child-revealed",
-                    G_CALLBACK (update_revealer_visibility), NULL);
-  g_signal_connect (header_bar->end_revealer, "notify::reveal-child",
-                    G_CALLBACK (update_revealer_visibility), NULL);
-  gtk_revealer_set_transition_type (GTK_REVEALER (header_bar->end_revealer), GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT);
-  gtk_container_add (GTK_CONTAINER (header_bar->end_revealer), GTK_WIDGET (header_bar->action_bar_end));
-
-  gtk_header_bar_pack_end (GTK_HEADER_BAR (header_bar->header_bar),
-                           GTK_WIDGET (header_bar->end_revealer));
+  adw_header_bar_pack_end (ADW_HEADER_BAR (header_bar->header_bar),
+                           GTK_WIDGET (header_bar->action_bar_end));
 
   /* Sync the size of placeholder in EphyActionBarStart with downloads button */
   downloads_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
@@ -364,8 +374,7 @@ ephy_header_bar_class_init (EphyHeaderBarClass *klass)
 
   object_properties[PROP_WINDOW] =
     g_param_spec_object ("window",
-                         "Window",
-                         "The header_bar's EphyWindow",
+                         NULL, NULL,
                          EPHY_TYPE_WINDOW,
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
@@ -418,19 +427,16 @@ void
 ephy_header_bar_set_adaptive_mode (EphyHeaderBar    *header_bar,
                                    EphyAdaptiveMode  adaptive_mode)
 {
-  ephy_action_bar_end_set_show_bookmark_button (header_bar->action_bar_end,
-                                                adaptive_mode == EPHY_ADAPTIVE_MODE_NARROW);
-
   switch (adaptive_mode) {
     case EPHY_ADAPTIVE_MODE_NORMAL:
-      gtk_revealer_set_reveal_child (GTK_REVEALER (header_bar->start_revealer), TRUE);
-      gtk_revealer_set_reveal_child (GTK_REVEALER (header_bar->end_revealer), TRUE);
+      gtk_widget_set_visible (GTK_WIDGET (header_bar->action_bar_start), TRUE);
+      gtk_widget_set_visible (GTK_WIDGET (header_bar->action_bar_end), TRUE);
       gtk_widget_set_visible (header_bar->combined_stop_reload_button, FALSE);
 
       break;
     case EPHY_ADAPTIVE_MODE_NARROW:
-      gtk_revealer_set_reveal_child (GTK_REVEALER (header_bar->start_revealer), FALSE);
-      gtk_revealer_set_reveal_child (GTK_REVEALER (header_bar->end_revealer), FALSE);
+      gtk_widget_set_visible (GTK_WIDGET (header_bar->action_bar_start), FALSE);
+      gtk_widget_set_visible (GTK_WIDGET (header_bar->action_bar_end), FALSE);
       gtk_widget_set_visible (header_bar->combined_stop_reload_button, TRUE);
 
       break;
@@ -445,16 +451,14 @@ ephy_header_bar_start_change_combined_stop_reload_state (EphyHeaderBar *header_b
                                                          gboolean       loading)
 {
   if (loading) {
-    gtk_image_set_from_icon_name (GTK_IMAGE (header_bar->combined_stop_reload_image),
-                                  "process-stop-symbolic",
-                                  get_icon_size ());
+    gtk_button_set_icon_name (GTK_BUTTON (header_bar->combined_stop_reload_button),
+                              "process-stop-symbolic");
     /* Translators: tooltip for the stop button */
     gtk_widget_set_tooltip_text (header_bar->combined_stop_reload_button,
                                  _("Stop loading the current page"));
   } else {
-    gtk_image_set_from_icon_name (GTK_IMAGE (header_bar->combined_stop_reload_image),
-                                  "view-refresh-symbolic",
-                                  get_icon_size ());
+    gtk_button_set_icon_name (GTK_BUTTON (header_bar->combined_stop_reload_button),
+                              "view-refresh-symbolic");
     gtk_widget_set_tooltip_text (header_bar->combined_stop_reload_button,
                                  _(REFRESH_BUTTON_TOOLTIP));
   }
@@ -468,10 +472,3 @@ ephy_header_bar_set_zoom_level (EphyHeaderBar *header_bar,
 
   gtk_label_set_label (GTK_LABEL (header_bar->zoom_level_label), zoom_level);
 }
-
-void
-ephy_header_bar_add_browser_action (EphyHeaderBar *header_bar,
-                                    GtkWidget     *action)
-{
-  ephy_action_bar_end_add_browser_action (header_bar->action_bar_end, action);
-}
