@@ -355,7 +355,7 @@ main (int   argc,
     g_error ("Fatal initialization error: %s", error->message);
   }
 
-  if (g_settings_get_boolean (EPHY_SETTINGS_MAIN, EPHY_PREFS_START_IN_INCOGNITO_MODE)) {
+  if (g_settings_get_boolean (EPHY_SETTINGS_MAIN, EPHY_PREFS_START_IN_INCOGNITO_MODE) && !application_mode && !open_in_new_window) {
     incognito_mode = TRUE;
   }
 
@@ -458,9 +458,12 @@ main (int   argc,
 
   status = g_application_run (G_APPLICATION (ephy_shell), argc, argv);
 
-  /* Shutdown */
-  /* FIXME: should free this stuff even when exiting early */
+  /* Ensure the EphyShell really gets destroyed. This should be the final reference. */
+  g_object_add_weak_pointer (G_OBJECT (ephy_shell), (gpointer *)&ephy_shell);
   g_object_unref (ephy_shell);
+  g_assert (!ephy_shell);
+
+  /* FIXME: should free this stuff even when exiting early */
   g_free (desktop_file_basename);
   g_free (profile_directory);
 
