@@ -396,6 +396,7 @@ static GActionEntry app_mode_app_entries[] = {
   { "run-in-background", NULL, NULL, "false", NULL},
 };
 
+#if 0
 static void
 register_synchronizable_managers (EphyShell       *shell,
                                   EphySyncService *service)
@@ -463,6 +464,7 @@ sync_secrets_load_finished_cb (EphySyncService *service,
   register_synchronizable_managers (shell, service);
   ephy_sync_service_start_sync (service);
 }
+#endif
 
 static void
 set_accel_for_action (EphyShell   *shell,
@@ -602,11 +604,13 @@ create_web_view_for_automation_cb (WebKitAutomationSession *session,
 
   window = EPHY_WINDOW (gtk_application_get_active_window (GTK_APPLICATION (shell)));
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  n_embeds = ephy_embed_container_get_n_children (EPHY_EMBED_CONTAINER (window));
-  web_view = ephy_embed_get_web_view (embed);
-  if (n_embeds == 1 && ephy_web_view_get_visit_type (web_view) == EPHY_PAGE_VISIT_HOMEPAGE) {
-    gtk_widget_grab_focus (GTK_WIDGET (embed));
-    return GTK_WIDGET (web_view);
+  if (embed) {
+    n_embeds = ephy_embed_container_get_n_children (EPHY_EMBED_CONTAINER (window));
+    web_view = ephy_embed_get_web_view (embed);
+    if (n_embeds == 1 && ephy_web_view_get_visit_type (web_view) == EPHY_PAGE_VISIT_HOMEPAGE) {
+      gtk_widget_grab_focus (GTK_WIDGET (embed));
+      return GTK_WIDGET (web_view);
+    }
   }
 
   embed = ephy_shell_new_tab (shell, window, NULL, EPHY_NEW_TAB_JUMP);
@@ -1159,6 +1163,9 @@ ephy_shell_get_sync_service (EphyShell *shell)
 {
   g_assert (EPHY_IS_SHELL (shell));
 
+#if 0
+  /* Firefox Sync is disabled due to: https://gitlab.gnome.org/GNOME/epiphany/-/issues/2337 */
+
   if (shell->sync_service == NULL) {
     shell->sync_service = ephy_sync_service_new (TRUE);
 
@@ -1171,6 +1178,7 @@ ephy_shell_get_sync_service (EphyShell *shell)
                              G_CALLBACK (sync_secrets_load_finished_cb),
                              shell, 0);
   }
+#endif
 
   return shell->sync_service;
 }
@@ -1485,7 +1493,7 @@ ephy_shell_open_uris_idle (OpenURIsData *data)
   else if (data->reuse_empty_tab) {
     embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (data->window));
     /* Only load a new page in this embed if it was showing or loading the homepage */
-    if (ephy_web_view_get_visit_type (ephy_embed_get_web_view (embed)) == EPHY_PAGE_VISIT_HOMEPAGE)
+    if (embed && ephy_web_view_get_visit_type (ephy_embed_get_web_view (embed)) == EPHY_PAGE_VISIT_HOMEPAGE)
       reusing_empty_tab = TRUE;
   }
 
