@@ -31,9 +31,10 @@
 #include "ephy-session.h"
 #include "ephy-sync-service.h"
 #include "ephy-web-extension-manager.h"
+#include "ephy-web-app-utils.h"
 #include "ephy-window.h"
 
-#include <webkit2/webkit2.h>
+#include <webkit/webkit.h>
 #include <glib-object.h>
 #include <glib.h>
 
@@ -131,11 +132,20 @@ void                     ephy_shell_send_notification       (EphyShell        *s
 
 gboolean                 ephy_shell_startup_finished        (EphyShell *shell);
 
-EphyWebExtensionManager  *ephy_shell_get_web_extension_manager (EphyShell        *shell);
-
 EphyWebView              *ephy_shell_get_web_view              (EphyShell        *shell,
                                                                 guint64           id);
 
 EphyWebView              *ephy_shell_get_active_web_view       (EphyShell        *shell);
 
+EphyWebApplication       *ephy_shell_get_webapp                (EphyShell        *shell);
+
+void                      ephy_shell_resync_title_boxes        (EphyShell        *shell,
+                                                                const char       *title,
+                                                                const char       *address);
+
+void                      ephy_shell_register_window           (EphyShell        *shell,
+                                                                EphyWindow       *window);
+void                      ephy_shell_unregister_window         (EphyShell        *shell,
+                                                                EphyWindow       *window);
+
 G_END_DECLS
