@@ -27,13 +27,13 @@
 #include "ephy-tab-view.h"
 #include "ephy-web-view.h"
 
-#include <handy.h>
+#include <adwaita.h>
 
 G_BEGIN_DECLS
 
 #define EPHY_TYPE_WINDOW (ephy_window_get_type ())
 
-G_DECLARE_FINAL_TYPE (EphyWindow, ephy_window, EPHY, WINDOW, HdyApplicationWindow)
+G_DECLARE_FINAL_TYPE (EphyWindow, ephy_window, EPHY, WINDOW, AdwApplicationWindow)
 
 typedef enum
 {
@@ -49,8 +49,8 @@ EphyWindow       *ephy_window_new                 (void);
 
 EphyTabView      *ephy_window_get_tab_view        (EphyWindow *window);
 
-void              ephy_window_open_pages_view     (EphyWindow *window);
-void              ephy_window_close_pages_view    (EphyWindow *window);
+void              ephy_window_toggle_tab_overview (EphyWindow *window);
+gboolean          ephy_window_is_tab_overview_open (EphyWindow *window);
 
 void              ephy_window_load_url            (EphyWindow *window,
                                                    const char *url);
@@ -89,12 +89,17 @@ gboolean          ephy_window_is_maximized               (EphyWindow *window);
 
 gboolean          ephy_window_is_fullscreen              (EphyWindow *window);
 
-void              ephy_window_get_geometry               (EphyWindow   *window,
-                                                          GdkRectangle *rectangle);
+GActionGroup     *ephy_window_get_action_group           (EphyWindow  *window,
+                                                          const char  *prefix);
 
 void              ephy_window_sync_bookmark_state        (EphyWindow            *window,
                                                           EphyBookmarkIconState  state);
 
 guint64           ephy_window_get_uid                    (EphyWindow *window);
 
+void              ephy_window_switch_to_new_tab_toast    (EphyWindow *window,
+                                                          GtkWidget  *tab);
+
+void              ephy_window_switch_to_new_tab          (EphyWindow *window);
+
 G_END_DECLS
