@@ -52,7 +52,7 @@
 #include <math.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <webkit2/webkit2.h>
+#include <webkit/webkit.h>
 
 static int do_step_n = -1;
 static int migration_version = -1;
@@ -674,7 +674,7 @@ migrate_sync_device_info (void)
   if (!ephy_sync_utils_user_is_signed_in ())
     return;
 
-  /* Fetch the device info from the Firefox Accounts Server. */
+  /* Fetch the device info from the Mozilla Accounts Server. */
   device = ephy_sync_debug_get_current_device ();
   if (!device) {
     g_warning ("Failed to migrate sync device info. Sign in again to Sync "
@@ -687,7 +687,7 @@ migrate_sync_device_info (void)
   ephy_sync_debug_erase_record ("clients", prev_device_id);
   ephy_sync_debug_erase_record ("tabs", prev_device_id);
 
-  /* Use the device id and name assigned by the Firefox Accounts Server at sign in.
+  /* Use the device id and name assigned by the Mozilla Accounts Server at sign in.
    * The user can change later the device name in the Preferences dialog. */
   device_id = json_object_get_string_member (device, "id");
   ephy_sync_utils_set_device_id (device_id);
@@ -1143,8 +1143,6 @@ migrate_profile_directories (void)
 {
   g_autoptr (GFile) new_directory = NULL;
   g_autoptr (GFile) adblock_directory = NULL;
-  g_autoptr (GFile) gsb_file = NULL;
-  g_autoptr (GFile) gsb_journal_file = NULL;
   GList *web_apps;
   GList *l;
 
@@ -1243,10 +1241,6 @@ migrate_profile_directories (void)
   new_directory = g_file_new_for_path (ephy_default_profile_dir ());
   adblock_directory = g_file_get_child (new_directory, "adblock");
   g_file_delete (adblock_directory, NULL, NULL);
-  gsb_file = g_file_get_child (new_directory, "gsb-threats.db");
-  g_file_delete (gsb_file, NULL, NULL);
-  gsb_journal_file = g_file_get_child (new_directory, "gsb-threats.db-journal");
-  g_file_delete (gsb_journal_file, NULL, NULL);
 }
 
 static void
@@ -1555,7 +1549,6 @@ migrate_pre_flatpak_webapps (void)
       g_autoptr (GKeyFile) keyfile = NULL;
       g_autoptr (GFile) app_link_file = NULL;
       g_autoptr (GFile) old_desktop_file = NULL;
-      g_autoptr (GFileInfo) file_info = NULL;
       const char *final_hyphen, *checksum;
       g_autofree char *new_name = NULL;
 
@@ -1681,6 +1674,19 @@ next:
   }
 }
 
+static void
+migrate_gsb_db (void)
+{
+  g_autofree char *threats_db = g_build_filename (ephy_default_cache_dir (), "gsb-threats.db", NULL);
+  g_autofree char *threats_db_journal = g_build_filename (ephy_default_cache_dir (), "gsb-threats.db-journal", NULL);
+
+  if (g_unlink (threats_db) == -1 && errno != ENOENT)
+    g_warning ("Failed to delete %s: %s", threats_db, g_strerror (errno));
+
+  if (g_unlink (threats_db_journal) == -1 && errno != ENOENT)
+    g_warning ("Failed to delete %s: %s", threats_db_journal, g_strerror (errno));
+}
+
 static void
 migrate_nothing (void)
 {
@@ -1734,6 +1740,7 @@ const EphyProfileMigrator migrators[] = {
   /* FIXME: Please also remove the "search-engines" deprecated gschema key when dropping this migrator in the future. */
   /* 36 */ migrate_search_engines_to_vardict,
   /* 37 */ migrate_pre_flatpak_webapps,
+  /* 38 */ migrate_gsb_db,
 };
 
 static gboolean
