@@ -164,9 +164,6 @@ void window_cmd_toggle_inspector                (GSimpleAction *action,
 void window_cmd_select_all                      (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
-void window_cmd_send_to                         (GSimpleAction *action,
-                                                 GVariant      *parameter,
-                                                 gpointer       user_data);
 void window_cmd_go_location                     (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
@@ -176,9 +173,6 @@ void window_cmd_location_search                 (GSimpleAction *action,
 void window_cmd_go_home                         (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
-void window_cmd_go_content                      (GSimpleAction *action,
-                                                 GVariant      *parameter,
-                                                 gpointer       user_data);
 void window_cmd_go_tabs_view                    (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
@@ -242,7 +236,7 @@ void window_cmd_change_tabs_mute_state          (GSimpleAction *action,
 void window_cmd_import_passwords                (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
-void window_cmd_extensions                      (GSimpleAction *action,
+void window_cmd_switch_new_tab                  (GSimpleAction *action,
                                                  GVariant      *parameter,
                                                  gpointer       user_data);
 
