@@ -38,47 +38,24 @@
 #define HTML_STRING "testing-ephy-web-view"
 #define SERVER_PORT 12321
 
-#if SOUP_CHECK_VERSION (2, 99, 4)
 static void
 server_callback (SoupServer        *server,
                  SoupServerMessage *msg,
                  const char        *path,
                  GHashTable        *query,
                  gpointer           data)
-#else
-static void
-server_callback (SoupServer        *server,
-                 SoupMessage       *msg,
-                 const char        *path,
-                 GHashTable        *query,
-                 SoupClientContext *context,
-                 gpointer           data)
-#endif
 {
   SoupMessageHeaders *response_headers;
   SoupMessageBody *response_body;
 
-#if SOUP_CHECK_VERSION (2, 99, 4)
   response_headers = soup_server_message_get_response_headers (msg);
   response_body = soup_server_message_get_response_body (msg);
-#else
-  response_headers = msg->response_headers;
-  response_body = msg->response_body;
-#endif
 
   if (!strcmp (path, "/redirect")) {
-#if SOUP_CHECK_VERSION (2, 99, 4)
     soup_server_message_set_status (msg, SOUP_STATUS_MOVED_PERMANENTLY, NULL);
-#else
-    soup_message_set_status (msg, SOUP_STATUS_MOVED_PERMANENTLY);
-#endif
     soup_message_headers_append (response_headers, "Location", "/redirect-result");
   } else {
-#if SOUP_CHECK_VERSION (2, 99, 4)
     soup_server_message_set_status (msg, SOUP_STATUS_OK, NULL);
-#else
-    soup_message_set_status (msg, SOUP_STATUS_OK);
-#endif
   }
 
 
@@ -168,10 +145,10 @@ test_ephy_web_view_load_url (void)
     URLTest test;
     GMainLoop *loop;
     EphyWebView *view;
-    GtkWidget *window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    GtkWidget *window = gtk_window_new ();
 
     view = EPHY_WEB_VIEW (ephy_web_view_new ());
-    gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET (view));
+    gtk_window_set_child (GTK_WINDOW (window), GTK_WIDGET (view));
     test = test_load_url[i];
     loop = g_main_loop_new (NULL, FALSE);
 
@@ -187,7 +164,7 @@ test_ephy_web_view_load_url (void)
 
     g_main_loop_run (loop);
     g_main_loop_unref (loop);
-    g_object_unref (g_object_ref_sink (view));
+    g_object_unref (window);
   }
 }
 
